Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(52)

Unified Diff: athena/main/athena_app_window_controller.h

Issue 412713002: Move apps/shell to extensions/shell. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: 40% Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « athena/main/DEPS ('k') | athena/main/athena_app_window_controller.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: athena/main/athena_app_window_controller.h
diff --git a/athena/main/athena_app_window_controller.h b/athena/main/athena_app_window_controller.h
index 78684d5623f50af6cefe5b4153e4ff33190f7b8f..ea2c17292d000f5c61a707ec115de97d62fa01d5 100644
--- a/athena/main/athena_app_window_controller.h
+++ b/athena/main/athena_app_window_controller.h
@@ -5,20 +5,20 @@
#ifndef ATHENA_MAIN_ATHENA_APP_WINDOW_CONTROLLER_H_
#define ATHENA_MAIN_ATHENA_APP_WINDOW_CONTROLLER_H_
-#include "apps/shell/browser/shell_app_window_controller.h"
#include "base/macros.h"
+#include "extensions/shell/browser/shell_app_window_controller.h"
namespace athena {
// The shell app window controller for athena. It embeds the web_contents of
// an app window into an Athena activity.
-class AthenaAppWindowController : public apps::ShellAppWindowController {
+class AthenaAppWindowController : public extensions::ShellAppWindowController {
public:
AthenaAppWindowController();
virtual ~AthenaAppWindowController();
- // Overridden from apps::ShellAppWindowController:
- virtual apps::ShellAppWindow* CreateAppWindow(
+ // Overridden from extensions::ShellAppWindowController:
+ virtual extensions::ShellAppWindow* CreateAppWindow(
content::BrowserContext* context) OVERRIDE;
virtual void CloseAppWindows() OVERRIDE;
« no previous file with comments | « athena/main/DEPS ('k') | athena/main/athena_app_window_controller.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698